/* GNU polyxmass - the massist's program.
   -------------------------------------- 
   Copyright (C) 2000,2001,2002 Filippo Rusconi

   http://www.polyxmass.org

   This file is part of the "GNU polyxmass" project.
   
   The "GNU polyxmass" project is an official GNU project package (see
   www.gnu.org) released ---in its entirety--- under the GNU General
   Public License and was started at the Centre National de la
   Recherche Scientifique (FRANCE), that granted me the formal
   authorization to publish it under this Free Software License.

   This software is free software; you can redistribute it and/or
   modify it under the terms of the GNU  General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.
   
   This software is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.
   
   You should have received a copy of the GNU  General Public
   License along with this software; if not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

/* to format the position of the * in pointers:
 * First operate this regexp replace: \([a-z]\)\* to \1 *
 * Next operate this regexp replace: \([a-z]\) \* \([a-z]\) to \1 *\2
 */


#ifndef PXMCHEM_GLOBALS_H
#define PXMCHEM_GLOBALS_H


#ifdef HAVE_CONFIG_H
#include "config.h"
#endif


#include <libpxmutils/pxmutils.h>



#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


/*
#define _(String) (String)
#define N_(String) String
#define textdomain(GETTEXT_PACKAGE)
#define bindtextdomain(GETTEXT_PACKAGE, LOCALEDIR)
*/

/* When ready for the gettext step, change lines above with:
 */
// #include <libintl.h>  replace with the wrapper ENABLE_NLS depending one:
#include "gettext.h" // see gettext manual page 111.
#define _(String) gettext (String) 
#define gettext_noop(String) String 
#define N_(String) gettext_noop (String)
/*
 */


#define debug_printf( x ) \
{ \
  printf ( "%s @ %u : ", __FILE__, __LINE__ ); \
  printf x; \
  fflush ( stdout ); \
}


#if 0

The way to change all the debug_printf statement into commented
material is by using the following sed script:

sed 's|debug_printf (\(.*\));|/\*debug_printf (\1);\*/|'

#endif







/*****************  GENERAL DEFINES AND ENUMS  ************************/



/* Chemical entities that may modify the outcome of a mass calculation
 * or of a formula calculation. We have two kinds of chemical entities,
 * the ones that apply onto the polymer, and the ones that apply onto
 * monomers.
 */
typedef enum _PxmEnd PxmEnd;
typedef enum _PxmFragEnd PxmFragEnd;
typedef enum _PxmMnmChement PxmMnmChement;
typedef enum _PxmPlmChement PxmPlmChement;
typedef enum _PxmMasscalcRes PxmMasscalcRes;
typedef enum _PxmCompcalcRes PxmCompcalcRes;
typedef enum _PxmCapping PxmCapping;
typedef enum _PxmMassType PxmMassType;
typedef enum _PxmMassTolerance PxmMassTolerance;
  

enum _PxmEnd
{
  PXM_END_NONE = 1 << 0,
  PXM_END_LEFT = 1 << 1,
  PXM_END_RIGHT = 1 << 2,
  PXM_END_BOTH = (PXM_END_LEFT | PXM_END_RIGHT)
};

enum _PxmFragEnd
{
  PXM_FRAG_END_NONE = 1 << 0,
  PXM_FRAG_END_LEFT = 1 << 1,
  PXM_FRAG_END_RIGHT = 1 << 2,
  PXM_FRAG_END_BOTH = (PXM_FRAG_END_LEFT | PXM_FRAG_END_RIGHT)
};


enum _PxmMnmChement
{
  PXMCHEMENT_MNM_NONE = 0,
  PXMCHEMENT_MNM_MODIF = 1
};

enum _PxmPlmChement
{
  PXMCHEMENT_PLM_NONE = 1 << 0,
  PXMCHEMENT_PLM_LEFT_MODIF = 1 << 1,
  PXMCHEMENT_PLM_RIGHT_MODIF = 1 << 2,
  PXMCHEMENT_PLM_BOTH_MODIF = 
  (PXMCHEMENT_PLM_LEFT_MODIF | PXMCHEMENT_PLM_RIGHT_MODIF)
};

enum _PxmCapping
{
  PXM_CAPPING_NONE = 1 << 0,
  PXM_CAPPING_LEFT = 1 << 1,
  PXM_CAPPING_RIGHT = 1 << 2,
  PXM_CAPPING_BOTH = (PXM_CAPPING_LEFT | PXM_CAPPING_RIGHT)
};

enum _PxmMasscalcRes
{
  PXM_MASSCALC_FAILURE,
  PXM_MASSCALC_SUCCESS
};

enum _PxmCompcalcRes
{
  PXM_COMPCALC_FAILURE,
  PXM_COMPCALC_SUCCESS
};

enum _PxmMassType
{
  PXM_MASS_NONE = 1 << 0,
  PXM_MASS_MONO = 1 << 1,
  PXM_MASS_AVG = 1 << 2,
  PXM_MASS_BOTH = (PXM_MASS_MONO | PXM_MASS_AVG)
};

enum _PxmMassTolerance
{
  PXM_MASS_TOLERANCE_AMU = 0,
  PXM_MASS_TOLERANCE_PCT,
  PXM_MASS_TOLERANCE_PPM
};

enum
{
  MODIF_FAILURE = 0,
  MODIF_SUCCESS = 1
};

enum
{
  UN_MODIF_FAILURE = 0,
  UN_MODIF_SUCCESS = 1,
  UN_MODIF_NO_MATCH,
  UN_MODIF_NO_MODIF
};

enum
{
  NONE,
  INC,
  DEC,
};


/* Globally available data structures and arrays.
 */
extern GPtrArray* pxmchem_atom_GPA;



/* The delimitor for separating monomer codes in a string.
 */
#define pxmchem_globals_delim '@'


/* Numerical formats for the different weighing species and related
 * functions. See pxmchem-globals.c for non-extern declaration.
 */
extern gchar* pxmchem_globals_atom_num_format;
extern gchar* pxmchem_globals_monomer_num_format;
extern gchar* pxmchem_globals_oligomer_num_format;
extern gchar* pxmchem_globals_polymer_num_format;

gchar*
pxmchem_globals_set_atom_num_format (gchar* fmt);


gchar*
pxmchem_globals_set_monomer_num_format (gchar* fmt);


gchar*
pxmchem_globals_set_oligomer_num_format (gchar* fmt);


gchar*
pxmchem_globals_set_polymer_num_format (gchar* fmt);

gint
pxmchem_globals_parse_masses_in_text (gchar *text,
				      GPtrArray *GPA);












#ifdef __cplusplus
}
#endif /* __cplusplus */



#endif /* PXMCHEM_GLOBALS_H */
