/* GNU polyxmass - the massist's program.
   -------------------------------------- 
   Copyright (C) 2000,2001,2002 Filippo Rusconi

   http://www.polyxmass.org

   This file is part of the "GNU polyxmass" project.
   
   The "GNU polyxmass" project is an official GNU project package (see
   www.gnu.org) released ---in its entirety--- under the GNU General
   Public License and was started at the Centre National de la
   Recherche Scientifique (FRANCE), that granted me the formal
   authorization to publish it under this Free Software License.

   This software is free software; you can redistribute it and/or
   modify it under the terms of the GNU  General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.
   
   This software is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.
   
   You should have received a copy of the GNU  General Public
   License along with this software; if not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef PXMCHEM_POLDEF_H
#define PXMCHEM_POLDEF_H

#include "pxmchem-globals.h"
#include "pxmchem-ionizerule.h"
#include "pxmchem-calcopt.h"

typedef struct _PxmPoldef PxmPoldef;

struct _PxmPoldef
{
  /* type identifies the polymer definition, like "protein" or "dna",
   * for example.
   */
  gchar *type;

  /* file fully qualifies the file which contains the polymer definition.
   */
  gchar *file;

  /* dir is the directory where all the housekeeping files and data
   * pertaining to a given polymer definition are stored. This is
   * the place where the monomer icon files are stored, for example.
   */
  gchar *dir;

  /* leftcap and rightcap are two actform strings that describe
   * how the polymer should be capped on its left and right ends.
   */
  gchar *leftcap;
  gchar *rightcap;

  gint codelen;
  
  /* A string made with each code of each monomer separated using '@',
   * like "@Ala@Tyr@Phe@".
   */
  gchar *delim_codes;

  /* A boolean value that tells if the polymer definition has been
   * modified or not. This is a convenience for the user of the 
   * PxmPoldef object.
   */
  gboolean modified;
  
  /* ionizerule is a PxmIonizerule structure that describes how 
   * the polymer is to be ionized.
   */
  PxmIonizerule *ionizerule;
  
  /* polymerGPA is an array of PxmPolymer instances which will hold
   * all the polymer sequences currently in memory that have the same
   * polymer type as type (which means that are of _this_ polymer
   * definition type.
   */
  GPtrArray *polymerGPA;
  
  /* The GPtrArray arrays that will hold all the polymer definition
   * data pertaining to the chemistry: monomers, modifs, cleavespecifs...
   */
  GPtrArray *monomerGPA;
  GPtrArray *modifGPA;
  GPtrArray *cleavespecGPA;
  GPtrArray *fragspecGPA;
  
  /* The conventional system of prop instances' array.
   */
  GPtrArray *propGPA;
};


/* NEW'ING FUNCTIONS, DUPLICATING FUNCTIONS, INITING FUNCTIONS ...
 */
PxmPoldef *
pxmchem_poldef_new (void);

gboolean
pxmchem_poldef_set_type (PxmPoldef * poldef, gchar *type);

gboolean
pxmchem_poldef_set_file (PxmPoldef * poldef, gchar *file);

gboolean
pxmchem_poldef_set_dir (PxmPoldef * poldef, gchar *dir);

gboolean
pxmchem_poldef_set_leftcap (PxmPoldef * poldef, gchar *leftcap);

gboolean
pxmchem_poldef_set_rightcap (PxmPoldef * poldef, gchar *rightcap);

gboolean
pxmchem_poldef_set_codelen (PxmPoldef *poldef, gint codelen);

gboolean
pxmchem_poldef_set_delim_codes (PxmPoldef * poldef, gchar *delim_codes);

void
pxmchem_poldef_set_modified (PxmPoldef *poldef, gboolean modified);


gboolean
pxmchem_poldef_get_modified (PxmPoldef *poldef);


gboolean
pxmchem_poldef_invert_modified (PxmPoldef *poldef);

gboolean
pxmchem_poldef_update_delim_codes (PxmPoldef * poldef, gchar delim);



/* INTEGRITY CHECKING FUNCTIONS
 */
gboolean
pxmchem_poldef_validate_all (PxmPoldef *poldef, gchar **valid);



/* LOCATING FUNCTIONS
 */
PxmPoldef *
pxmchem_poldef_get_ptr_by_type (GPtrArray *GPA, gchar *type);


gint
pxmchem_poldef_get_index_by_type (GPtrArray *GPA, gchar *type);


gint
pxmchem_poldef_get_index_by_ptr (GPtrArray *GPA, PxmPoldef *poldef);



/* UTILITY FUNCTIONS
 */
gchar*
pxmchem_poldef_make_delim_codes (PxmPoldef *poldef, gchar delim);


/* XML-format TRANSACTIONS
 */
gchar *
pxmchem_poldef_format_xml_string_DTD (void);


gchar *
pxmchem_poldef_format_xml_string_poldefdata (PxmPoldef *poldef, 
					     gchar *indent, gint offset);

PxmPoldef *
pxmchem_poldef_render_xml_node_poldefdata (xmlDocPtr xml_doc,
					   xmlNodePtr xml_node,
					   gpointer user_data);

PxmPoldef *
pxmchem_poldef_render_xml_file (gchar *file);



/* FREE'ING FUNCTIONS
 */
gboolean
pxmchem_poldef_free (PxmPoldef *poldef);


/* GPtrArray-RELATED FUNCTIONS
 */
gint
pxmchem_poldef_GPA_free (GPtrArray *GPA);


#endif
